==> haskell-curve25519-0.2.8-10-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-curve25519.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 curve25519
version:              0.2.8
visibility:           public
id:                   curve25519-0.2.8-J77fnZKFb6C80BfOJQK9aP
key:                  curve25519-0.2.8-J77fnZKFb6C80BfOJQK9aP
license:              BSD-3-Clause
maintainer:           Adam Wick <awick@uhsure.com>
author:               Adam Wick <awick@uhsure.com>
homepage:             http://github.com/acw/curve25519
synopsis:
    Fast implementations of the curve25519 elliptic curve primitives.

description:
    Haskell bindings and extensions to the curve25519-donna
    codebase. This module is a pretty straightforward implementation
    of the basic cryptographic routines you'\''d want from a project that
    uses curve25519: key generation, and key agreement. For further
    functionality, you'\''ll want to look elsewhere.

category:             Math
abi:                  75c5b06212c172b5d1cc5f8279f7d984
exposed:              True
exposed-modules:
    Crypto.Curve25519 Crypto.Curve25519.Exceptions
    Crypto.Curve25519.Pure

import-dirs:          /usr/lib/ghc-9.2.8/site-local/curve25519-0.2.8
library-dirs:         /usr/lib/ghc-9.2.8/site-local/curve25519-0.2.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-curve25519
hs-libraries:         HScurve25519-0.2.8-J77fnZKFb6C80BfOJQK9aP
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    crypto-api-0.13.3-95IFBy4WvL6L3p6UFm5MLc

haddock-interfaces:   /usr/share/doc/haskell-curve25519/html/curve25519.haddock
haddock-html:         /usr/share/doc/haskell-curve25519/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-curve25519-0.2.8-12-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-curve25519.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 curve25519
version:              0.2.8
visibility:           public
id:                   curve25519-0.2.8-74d5he4fH3I6Yy9TLRZoVh
key:                  curve25519-0.2.8-74d5he4fH3I6Yy9TLRZoVh
license:              BSD-3-Clause
maintainer:           Adam Wick <awick@uhsure.com>
author:               Adam Wick <awick@uhsure.com>
homepage:             http://github.com/acw/curve25519
synopsis:
    Fast implementations of the curve25519 elliptic curve primitives.

description:
    Haskell bindings and extensions to the curve25519-donna
    codebase. This module is a pretty straightforward implementation
    of the basic cryptographic routines you'\''d want from a project that
    uses curve25519: key generation, and key agreement. For further
    functionality, you'\''ll want to look elsewhere.

category:             Math
abi:                  4f099a82c2fdcea2682da93e2e162731
exposed:              True
exposed-modules:
    Crypto.Curve25519 Crypto.Curve25519.Exceptions
    Crypto.Curve25519.Pure

import-dirs:          /usr/lib/ghc-9.2.8/site-local/curve25519-0.2.8
library-dirs:         /usr/lib/ghc-9.2.8/site-local/curve25519-0.2.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-curve25519
hs-libraries:         HScurve25519-0.2.8-74d5he4fH3I6Yy9TLRZoVh
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    crypto-api-0.13.3-95IFBy4WvL6L3p6UFm5MLc

haddock-interfaces:   /usr/share/doc/haskell-curve25519/html/curve25519.haddock
haddock-html:         /usr/share/doc/haskell-curve25519/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
